@@ -55,6 +55,7 @@ pub enum Proc {
     Exec,
     Track(libc::pid_t),
     Trackerr,
+    Child(libc::pid_t),
 }
 
 // These need to be OS specific
@@ -100,10 +101,8 @@ impl PartialEq<Ident> for Ident {
                 } else {
                     false
                 }
-            },
-            _ => {
-                self.as_usize() == other.as_usize()
             }
+            _ => self.as_usize() == other.as_usize(),
         }
     }
 }
@@ -135,6 +134,24 @@ impl Watcher {
         }
     }
 
+    pub fn add_pid(&mut self,
+                   pid: libc::pid_t,
+                   filter: EventFilter,
+                   flags: FilterFlag)
+                   -> Result<()> {
+        let watch = Watched {
+            filter: filter,
+            flags: flags,
+            ident: Ident::Pid(pid),
+        };
+
+        if !self.watched.contains(&watch) {
+            self.watched.push(watch);
+        }
+
+        Ok(())
+    }
+
     pub fn add_filename<P: AsRef<Path>>(&mut self,
                                         filename: P,
                                         filter: EventFilter,
@@ -148,7 +165,7 @@ impl Watcher {
                                    filename.as_ref().to_string_lossy().into_owned()),
         };
 
-        if ! self.watched.contains(&watch) {
+        if !self.watched.contains(&watch) {
             self.watched.push(watch);
         }
 
@@ -162,7 +179,7 @@ impl Watcher {
             ident: Ident::Fd(fd),
         };
 
-        if ! self.watched.contains(&watch) {
+        if !self.watched.contains(&watch) {
             self.watched.push(watch);
         }
 
@@ -199,6 +216,22 @@ impl Watcher {
         }
     }
 
+    pub fn remove_pid(&mut self, pid: libc::pid_t, filter: EventFilter) -> Result<()> {
+        let new_watched = self.watched
+            .drain(..)
+            .filter(|x| {
+                if let Ident::Pid(iterpid) = x.ident {
+                    iterpid != pid
+                } else {
+                    true
+                }
+            })
+            .collect();
+
+        self.watched = new_watched;
+        self.delete_kevents(Ident::Pid(pid), filter)
+    }
+
     pub fn remove_filename<P: AsRef<Path>>(&mut self,
                                            filename: P,
                                            filter: EventFilter)
@@ -309,7 +342,6 @@ impl Drop for Watcher {
     }
 }
 
-#[inline]
 fn find_file_ident(watcher: &Watcher, fd: RawFd) -> Option<Ident> {
     for watched in &watcher.watched {
         match watched.ident.clone() {
@@ -334,7 +366,6 @@ fn find_file_ident(watcher: &Watcher, fd: RawFd) -> Option<Ident> {
     None
 }
 
-#[inline]
 fn get_event(watcher: &Watcher, timeout: Option<Duration>) -> Option<Event> {
     let mut kev = kevent {
         ident: 0,
@@ -364,6 +395,7 @@ fn get_event(watcher: &Watcher, timeout: Option<Duration>) -> Option<Event> {
 }
 
 // OS specific
+// TODO: Events can have more than one filter flag
 impl Event {
     pub fn new(ev: kevent, watcher: &Watcher) -> Event {
         let data = match ev.filter {
@@ -380,8 +412,10 @@ impl Event {
                     Proc::Exec
                 } else if ev.fflags.contains(NOTE_TRACK) {
                     Proc::Track(ev.data as libc::pid_t)
+                } else if ev.fflags.contains(NOTE_CHILD) {
+                    Proc::Child(ev.data as libc::pid_t)
                 } else {
-                    panic!("not supported")
+                    panic!("not supported: {:?}", ev.fflags)
                 };
 
                 EventData::Proc(inner)
@@ -443,7 +477,6 @@ impl Event {
         }
     }
 
-    #[inline]
     pub fn is_err(&self) -> bool {
         match self.data {
             EventData::Error(_) => true,
